#!/usr/bin/perl

# author: Byron Servies
#       Sun Microsystems, Inc.
# version: 1.0
# date: 01/17/01
#
# Copyright (C) 1999-2001, Sun Microsystems, Inc.
# All rights reserved

# This CGI handles 2 different cases:
#
# 	- License agreement
# 	- Configuration changes 
#
# License Agreement
#
# 	When the page parameter passed to the CGI has the value
#	'netbackup_license', then we know that we are working with the
# 	licensing page.  This page will only submit if the user agrees
#	to the license, so we are free to then install Veritas NetBackup
#	and configure it according to the hidden embedded parameters.
#
# Configuration Changes
#
#	When the page parameter passed to the CGI has the value 'netbackup',
#	we are going to either install and configure, or reconfigure the
#	NetBackup service.  If NetBackup is not installed, then we return
#	the licensing page from the template and wait for the next CGI.
#	If NetBackup is installed, then we reconfigure the service based on
#	the CGI values.
# 
use Cobalt::Product;
use Cobalt::Locale;
use Cobalt::NetBackup;
require Cobalt::Services;

use CGI;
use Locale::gettext;

# global variables
my $q=new CGI;
my $page=$q->param( 'page' );
my $netbackup_script_url='/cgi-bin/.cobalt/netbackup/netbackup.cgi';
my $services_script_url='/cgi-bin/.cobalt/services/services.cgi';
my $locale=Cobalt::Locale->getByHTTPHeader( $ENV{ 'HTTP_ACCEPT_LANGUAGE' } );
if( $locale ) { $ENV{ 'LANGUAGE' }=$locale->getLocale(); }

# Determine what action to take based on the page
if ($page eq 'netbackup') {
	# Call the routine to configure the service
	&netbackup_configure();
} else {
	# Generate the configuration page
	&netbackup_settings_page(\*STDOUT);
}


sub netbackup_configure
# Description: This routine handles configuration CGIs.  The parameters
# masterserver and extraservers contain lists of servers for NetBackup to
# listen to for connection requrests.
# Inputs: global cgi information
# Outputs: configuration html page or services page
{
	my $err=0;
	my ($masterserver, $extra, @extraservers, $result);
	my $info='<IMG SRC="/.cobalt/images/bang" ALIGN=CENTER>';

	# Re-configure the service based on the CGI parameters
	$masterserver = $q->param('masterserver');
	foreach $extra (split /\s+/, join " ", $q->param('extraservers')) {
		next if ($extra =~ /^\s*$/o);
		push @extraservers, ($extra);
	}

	$result = Cobalt::NetBackup::configure($masterserver, @extraservers);
	if ($result !~ /^2/) {
		$info .= substr($result, 4) . '<BR>';
		$err = 1;
	}

	if ($err) {
		# An error occurred.  Return the original page with the
		# error text.
		&netbackup_settings_page(\*STDOUT, $info);
	} else {
		# Redirect to the services script URL
		print "location: $services_script_url\n\n";
	}
}


sub netbackup_settings_page
# Description: Performs substitutions on the NetBackup settings template and
# returns the resultant HTML to the given file handle.
# Inputs: file handle
# Outputs: html
{
	my ($handle, $userinfo)=@_;
	my ($masterserver, @extraservers) =
		 Cobalt::NetBackup::get_servers();
	my $tfile = "$Template_dir/netbackup.tmpl";
	my $extratext = join "\n", @extraservers;

	print "content-type: text/html \nCache-Control: no-cache\n\n"; 
	open(TEMPLATE, $tfile) || die "Cannot read $tfile: $!\n";
	while (<TEMPLATE>) {
		s/\[MASTERSERVER\]/$masterserver/o;
		s/\[EXTRASERVERS\]/$extratext/o;
		s/\[SERVICESSCRIPTURL\]/$services_script_url/o;
		s/\[SCRIPTURL\]/$netbackup_script_url/o;
		s/\[USER_INFO\]/$userinfo/o;
		s/\[str.([^\]]+)\]/Locale::gettext::dgettext("ui", "$1")/geo;
		print $handle $_;
	}
	close(TEMPLATE);
}

